/**
 * Copyright © schukai GmbH and all contributing authors, {{copyRightYear}}. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 *
 * SPDX-License-Identifier: AGPL-3.0
 */

import { extend } from "../../../data/extend.mjs";
import { isArray } from "../../../types/is.mjs";
import { validateBoolean } from "../../../types/validate.mjs";

export { setEventListenersModifiers, popperInstanceSymbol };

/**
 * @private
 * @type {symbol}
 */
const popperInstanceSymbol = Symbol("popperInstance");

/**
 * @private
 * @this {CustomElement}
 * @param {Boolean} mode
 */
function setEventListenersModifiers(mode) {
	const options = extend({}, this.getOption("popper"));
	const modifiers = options?.["modifiers"];

	if (!isArray(modifiers)) {
		options["modifiers"] = [];
	}

	if (
		options["modifiers"].filter((entry) => {
			if (entry?.["name"] === "eventListeners") {
				// performance https://popper.js.org/docs/v2/tutorial/#performance
				entry["enabled"] = validateBoolean(mode);
			}
		}).length === 0
	) {
		options["modifiers"].push({
			name: "eventListeners",
			enabled: validateBoolean(mode),
		});
	}

	this[popperInstanceSymbol].setOptions(options);
}
