/**
 * Copyright © schukai GmbH and all contributing authors, 2025. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 */

import { addAttributeToken } from "../../../dom/attributes.mjs";
import { ATTRIBUTE_ERRORMESSAGE } from "../../../dom/constants.mjs";

export { IframeStyleSheet };

/**
 * @private
 * @type {CSSStyleSheet}
 */
const IframeStyleSheet = new CSSStyleSheet();

try {
	IframeStyleSheet.insertRule(
		`
@layer iframe { 
:host{border:none;box-sizing:border-box;display:block;height:-webkit-fill-available;height:fill-available;height:-moz-available;margin:0;padding:0}iframe{display:block}[data-monster-role=control],iframe{border:none;box-sizing:border-box;height:-webkit-fill-available;height:-moz-available;height:fill-available;height:stretch;margin:0;padding:0;width:100%}[data-monster-role=control]{align-items:center;display:flex;flex-direction:column;justify-content:center} 
}`,
		0,
	);
} catch (e) {
	addAttributeToken(
		document.getRootNode().querySelector("html"),
		ATTRIBUTE_ERRORMESSAGE,
		e + "",
	);
}
