/**
 * Copyright © schukai GmbH and all contributing authors, 2025. All rights reserved.
 * Node module: @schukai/monster
 *
 * This source code is licensed under the GNU Affero General Public License version 3 (AGPLv3).
 * The full text of the license can be found at: https://www.gnu.org/licenses/agpl-3.0.en.html
 *
 * For those who do not wish to adhere to the AGPLv3, a commercial license is available.
 * Acquiring a commercial license allows you to use this software without complying with the AGPLv3 terms.
 * For more information about purchasing a commercial license, please contact schukai GmbH.
 */

import { addAttributeToken } from "../../dom/attributes.mjs";
import { ATTRIBUTE_ERRORMESSAGE } from "../../dom/constants.mjs";

export { HostStyleSheet };

/**
 * @private
 * @type {CSSStyleSheet}
 */
const HostStyleSheet = new CSSStyleSheet();

try {
	HostStyleSheet.insertRule(
		`
@layer host { 
:host([disabled]),:host([disabled]) *{background-color:var(--monster-bg-color-primary-3,inherit);border-color:var(--monster-color-primary-3,inherit);color:var(--monster-color-primary-3,inherit)}:disabled{background-color:var(--monster-bg-color-primary-3,inherit);border-color:var(--monster-color-primary-3,inherit);color:var(--monster-color-primary-3,inherit);cursor:not-allowed;opacity:.55;pointer-events:none} 
}`,
		0,
	);
} catch (e) {
	addAttributeToken(
		document.getRootNode().querySelector("html"),
		ATTRIBUTE_ERRORMESSAGE,
		e + "",
	);
}
